@@ -1,6 +1,6 @@
 #-----------------------------------------------------------------------------
 #
-#	$Id : Styles.pm 1.003 2004-03-07 JMG$		(c) GENICORP 2004
+#	$Id : Styles.pm 1.003 2004-03-11 JMG$
 #
 #	Initial developer: Jean-Marie Gouarne
 #	Copyright 2004 by Genicorp, S.A. (www.genicorp.com)
@@ -1196,9 +1196,3 @@ sub	removeStyle
 
 #-----------------------------------------------------------------------------
 1;
-
-=head1	NAME
-
-OpenOffice::OODoc::Styles - Interface for styles & layout processing
-
-=cut
